@@ -35,6 +35,7 @@ from randomizer.Enums.Settings import (
     ProgressiveHintItem,
     PuzzleRando,
     RandomPrices,
+    RandomStartingRegion,
     RandomRequirement,
     RemovedBarriersSelected,
     ShufflePortLocations,
@@ -255,8 +256,8 @@ def get_default_settings() -> dict:
         "random_crates": False,
         "random_fairies": False,
         "random_patches": False,
-        "random_prices": RandomPrices.free,
         "random_starting_region": False,
+        "random_starting_region_new": RandomStartingRegion.off,
         "randomize_enemy_sizes": False,
         "randomize_pickups": False,
         "rareware_gb_fairies": 6,
@@ -264,8 +265,8 @@ def get_default_settings() -> dict:
         "select_keys": False,
         "serious_hints": True,
         "shop_indicator": True,
-        "shops_dont_cost": False,
         "shorten_boss": True,
+        "shops_dont_cost": True,
         "shuffle_helm_location": False,
         "shuffle_shops": False,
         "smaller_shops": False,
