@@ -111,7 +111,7 @@ ItemList = {
     Items.Swim: Item("Diving", True, Types.TrainingBarrel, Kongs.any, [MoveTypes.Flag, "dive", 386]),
     Items.Oranges: Item("Oranges", True, Types.TrainingBarrel, Kongs.any, [MoveTypes.Flag, "orange", 388]),
     Items.Barrels: Item("Barrels", True, Types.TrainingBarrel, Kongs.any, [MoveTypes.Flag, "barrel", 389]),
-    Items.Climbing: Item("Climbing", True, Types.Climbing, Kongs.any, [MoveTypes.Flag, "climbing", 0x297]),
+    Items.Climbing: Item("Climbing", True, Types.Climbing, Kongs.any, [MoveTypes.Flag, "climbing", 0x29F]),
     Items.ProgressiveSlam: Item("Progressive Slam", True, Types.Shop, Kongs.any, [MoveTypes.Slam, 2, -1]),
     Items.ProgressiveSlam2: Item("Progressive Slam ", False, Types.Constant, Kongs.any),  # Only used for the starting move list selector modal
     Items.ProgressiveSlam3: Item("Progressive Slam  ", False, Types.Constant, Kongs.any),  # Only used for the starting move list selector modal
@@ -232,6 +232,18 @@ ItemList = {
     Items.IceTrapSlipBean: Item("Ice Trap (Slip - Bean)", False, Types.FakeItem, Kongs.any),
     Items.IceTrapSlipKey: Item("Ice Trap (Slip - Key)", False, Types.FakeItem, Kongs.any),
     Items.IceTrapSlipFairy: Item("Ice Trap (Slip - Fairy)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapAnimalGB: Item("Ice Trap (Animal - GB)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapAnimalBean: Item("Ice Trap (Animal - Bean)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapAnimalKey: Item("Ice Trap (Animal - Key)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapAnimalFairy: Item("Ice Trap (Animal - Fairy)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapRockfallGB: Item("Ice Trap (Rockfall - GB)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapRockfallBean: Item("Ice Trap (Rockfall - Bean)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapRockfallKey: Item("Ice Trap (Rockfall - Key)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapRockfallFairy: Item("Ice Trap (Rockfall - Fairy)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapDisableTagGB: Item("Ice Trap (Disable Tag - GB)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapDisableTagBean: Item("Ice Trap (Disable Tag - Bean)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapDisableTagKey: Item("Ice Trap (Disable Tag - Key)", False, Types.FakeItem, Kongs.any),
+    Items.IceTrapDisableTagFairy: Item("Ice Trap (Disable Tag - Fairy)", False, Types.FakeItem, Kongs.any),
     Items.JunkCrystal: Item("Junk Item (Crystal)", False, Types.JunkItem, Kongs.any),
     Items.JunkMelon: Item("Junk Item (Melon Slice)", False, Types.JunkItem, Kongs.any),
     Items.JunkAmmo: Item("Junk Item (Ammo Crate)", False, Types.JunkItem, Kongs.any),
@@ -374,6 +386,12 @@ ItemList = {
     Items.PhotoBug: Item("Photo (Bug)", False, Types.EnemyPhoto, Kongs.any),
     Items.PhotoKop: Item("Photo (Kop)", False, Types.EnemyPhoto, Kongs.any),
     Items.PhotoTomato: Item("Photo (Tomato)", False, Types.EnemyPhoto, Kongs.any),
+    Items.PhotoBFI: Item("Photo (BFI Queen)", False, Types.EnemyPhoto, Kongs.any),
+    Items.PhotoIceTomato: Item("Photo (Ice Tomato)", False, Types.EnemyPhoto, Kongs.any),
+    Items.PhotoMermaid: Item("Photo (Mermaid)", False, Types.EnemyPhoto, Kongs.any),
+    Items.PhotoLlama: Item("Photo (Llama)", False, Types.EnemyPhoto, Kongs.any),
+    Items.PhotoMechfish: Item("Photo (Mechfish)", False, Types.EnemyPhoto, Kongs.any),
+    Items.PhotoSeal: Item("Photo (Seal)", False, Types.EnemyPhoto, Kongs.any),
 }
 
 HHItemSelector = []
