@@ -60,6 +60,18 @@ IceTrapMasks = {
     Items.IceTrapSlipBean: Types.Bean,
     Items.IceTrapSlipKey: Types.Key,
     Items.IceTrapSlipFairy: Types.Fairy,
+    Items.IceTrapAnimalGB: Types.Banana,
+    Items.IceTrapAnimalBean: Types.Bean,
+    Items.IceTrapAnimalKey: Types.Key,
+    Items.IceTrapAnimalFairy: Types.Fairy,
+    Items.IceTrapRockfallGB: Types.Banana,
+    Items.IceTrapRockfallBean: Types.Bean,
+    Items.IceTrapRockfallKey: Types.Key,
+    Items.IceTrapRockfallFairy: Types.Fairy,
+    Items.IceTrapDisableTagGB: Types.Banana,
+    Items.IceTrapDisableTagBean: Types.Bean,
+    Items.IceTrapDisableTagKey: Types.Key,
+    Items.IceTrapDisableTagFairy: Types.Fairy,
 }
 IceTrapMaskIndexes = [Types.Banana, Types.Bean, Types.Key, Types.Fairy]
 
@@ -192,6 +204,10 @@ class CustomActors(IntEnum):
     FoolsArchipelagoItem = auto()
     TrapArchipelagoItem = auto()
     SpreadCounter = auto()
+    GuardDisableA = auto()
+    GuardDisableZ = auto()
+    GuardGetOut = auto()
+    GuardTag = auto()
 
 
 class GraphicOverlay(IntEnum):
@@ -1210,6 +1226,18 @@ item_shop_text_mapping = {
     Items.IceTrapSlipBean: (BuyText.ice_trap, NoBuyText.misc_item),
     Items.IceTrapSlipKey: (BuyText.ice_trap, NoBuyText.misc_item),
     Items.IceTrapSlipFairy: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapAnimalGB: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapAnimalBean: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapAnimalKey: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapAnimalFairy: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapRockfallGB: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapRockfallBean: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapRockfallKey: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapRockfallFairy: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapDisableTagGB: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapDisableTagBean: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapDisableTagKey: (BuyText.ice_trap, NoBuyText.misc_item),
+    Items.IceTrapDisableTagFairy: (BuyText.ice_trap, NoBuyText.misc_item),
     # Items not yet considered
     # Items.RainbowCoin: (BuyText.blueprint, NoBuyText.misc_item),
     # Items.FillerRainbowCoin: (BuyText.blueprint, NoBuyText.misc_item),
